;;; -*- mode: lisp -*-
;;;
;;; lj-clos.lisp --- class library & methods for working with lj
;;;
;;; Copyright (C) 2001 by Mark Simpson
;;;
;;; Author: Mark Simpson <damned@rover>
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, you can either send email to this
;;; program's maintainer or write to: The Free Software Foundation,
;;; Inc.; 675 Massachusetts Avenue; Cambridge, MA 02139, USA.
;;;
;;; Commentary: 

;;; Code:

(eval-when (:compile-toplevel :load-toplevel :execute)
  (require "lj-pkg" (logical-pathname "livejournal:lj-pkg"))
  (require "lj-util" (logical-pathname "livejournal:lj-util"))
  (require "lj" (logical-pathname "livejournal:lj")))

(in-package "LIVEJOURNAL")

(defclass friend ()
  ((user :initarg :user :reader username :initform "" :type 'string)
   (name :initarg :name :reader realname :initform "" :type 'string)
   (bg :initarg :bg :reader bg-color :initform "" :type 'string)
   (fg :initarg :fg :reader fg-color :initform "" :type 'string)
   (type :initarg :type :reader type :initform "" :type 'string)))

(defun get-friend-list ()
  (let* ((data (getfriends))
         (num-friends (get-info "friend_count" data :type 'num)))
    (flet ((get-info (n post-tag)
                            (get-nth-info "friend" n post-tag data)))
      (loop for n from 1 upto num-friends
            collect (make-instance 'friend
                                   :user (get-info n "user")
                                   :name (get-info n "name")
                                   :bg (get-info n "bg")
                                   :fg (get-info n "fg")
                                   :type (get-info n "type"))))))

(defun get-friendof-list ()
  (let* ((data (friendof))
         (num-friendof (get-info "friendof_count" data :type 'num)))
    (flet ((get-info (n tag)
                     (get-nth-info "friendsof" n tag data)))
      (loop for n from 1 upto num-friendof
            collect (make-instance 'friend
                                   :user (get-info n "user")
                                   :name (get-info n "name")
                                   :bg (get-info n "bg")
                                   :fg (get-info n "fg")
                                   :type (get-info n "type"))))))
  
(defclass event ()
  ((subject :initarg :subject :reader subject :initform "" :type 'string)
   (id :initarg :id :reader itemid :initform "" :type 'string)
   (time :initarg :time :reader eventtime :initform 0 :type 'string)
   (text :initarg :text :reader text :initform "" :type 'string)
   (action :initarg :action :reader action :initform "" :type 'string)))

(defun get-syncitem-list (&rest args)
  (let* ((data (apply #'syncitems args))
         (num-items (get-info "sync_count" data :type 'num))
         (total-num (get-info "sync_total" data :type 'num)))
    (flet ((get-info (n tag) (get-info "sync" n tag data)))
      (values (loop for n from 1 upto num-items
                    collect (make-instance 'event
                                           :subject ""
                                           :id (get-info n "item")
                                           :time (get-info n "time")
                                           :text ""
                                           :action (get-info n "action")))
              num-items
              total-num))))

(provide 'lj-clos)

;;; lj-clos.lisp ends here